@@ -126,7 +126,12 @@ class JWTAuthentication(authentication.BaseAuthentication):
         return user
 
 
-class JWTTokenUserAuthentication(JWTAuthentication):
+class JWTStatelessUserAuthentication(JWTAuthentication):
+    """
+    An authentication plugin that authenticates requests through a JSON web
+    token provided in a request header without performing a database lookup to obtain a user instance.
+    """
+
     def get_user(self, validated_token):
         """
         Returns a stateless user object which is backed by the given validated
@@ -140,6 +145,9 @@ class JWTTokenUserAuthentication(JWTAuthentication):
         return api_settings.TOKEN_USER_CLASS(validated_token)
 
 
+JWTTokenUserAuthentication = JWTStatelessUserAuthentication
+
+
 def default_user_authentication_rule(user):
     # Prior to Django 1.10, inactive users could be authenticated with the
     # default `ModelBackend`.  As of Django 1.10, the `ModelBackend`
