@@ -1,3 +1,7 @@
+import json
+from datetime import timedelta
+from typing import Optional, Type, Union
+
 import jwt
 from django.utils.translation import gettext_lazy as _
 from jwt import InvalidAlgorithmError, InvalidTokenError, algorithms
@@ -6,7 +10,7 @@ from .exceptions import TokenBackendError
 from .utils import format_lazy
 
 try:
-    from jwt import PyJWKClient
+    from jwt import PyJWKClient, PyJWKClientError
 
     JWK_CLIENT_AVAILABLE = True
 except ImportError:
@@ -34,7 +38,8 @@ class TokenBackend:
         audience=None,
         issuer=None,
         jwk_url: str = None,
-        leeway=0,
+        leeway: Union[float, int, timedelta] = None,
+        json_encoder: Optional[Type[json.JSONEncoder]] = None,
     ):
         self._validate_algorithm(algorithm)
 
@@ -48,7 +53,9 @@ class TokenBackend:
             self.jwks_client = PyJWKClient(jwk_url) if jwk_url else None
         else:
             self.jwks_client = None
+
         self.leeway = leeway
+        self.json_encoder = json_encoder
 
     def _validate_algorithm(self, algorithm):
         """
@@ -67,12 +74,32 @@ class TokenBackend:
                 )
             )
 
+    def get_leeway(self) -> timedelta:
+        if self.leeway is None:
+            return timedelta(seconds=0)
+        elif isinstance(self.leeway, (int, float)):
+            return timedelta(seconds=self.leeway)
+        elif isinstance(self.leeway, timedelta):
+            return self.leeway
+        else:
+            raise TokenBackendError(
+                format_lazy(
+                    _(
+                        "Unrecognized type '{}', 'leeway' must be of type int, float or timedelta."
+                    ),
+                    type(self.leeway),
+                )
+            )
+
     def get_verifying_key(self, token):
         if self.algorithm.startswith("HS"):
             return self.signing_key
 
         if self.jwks_client:
-            return self.jwks_client.get_signing_key_from_jwt(token).key
+            try:
+                return self.jwks_client.get_signing_key_from_jwt(token).key
+            except PyJWKClientError as ex:
+                raise TokenBackendError(_("Token is invalid or expired")) from ex
 
         return self.verifying_key
 
@@ -86,7 +113,12 @@ class TokenBackend:
         if self.issuer is not None:
             jwt_payload["iss"] = self.issuer
 
-        token = jwt.encode(jwt_payload, self.signing_key, algorithm=self.algorithm)
+        token = jwt.encode(
+            jwt_payload,
+            self.signing_key,
+            algorithm=self.algorithm,
+            json_encoder=self.json_encoder,
+        )
         if isinstance(token, bytes):
             # For PyJWT <= 1.7.1
             return token.decode("utf-8")
@@ -108,7 +140,7 @@ class TokenBackend:
                 algorithms=[self.algorithm],
                 audience=self.audience,
                 issuer=self.issuer,
-                leeway=self.leeway,
+                leeway=self.get_leeway(),
                 options={
                     "verify_aud": self.audience is not None,
                     "verify_signature": verify,
@@ -116,5 +148,5 @@ class TokenBackend:
             )
         except InvalidAlgorithmError as ex:
             raise TokenBackendError(_("Invalid algorithm specified")) from ex
-        except InvalidTokenError:
-            raise TokenBackendError(_("Token is invalid or expired"))
+        except InvalidTokenError as ex:
+            raise TokenBackendError(_("Token is invalid or expired")) from ex
