@@ -16,15 +16,15 @@ class DetailDictMixin:
         Builds a detail dictionary for the error to give more information to API
         users.
         """
-        detail_dict = {'detail': self.default_detail, 'code': self.default_code}
+        detail_dict = {"detail": self.default_detail, "code": self.default_code}
 
         if isinstance(detail, dict):
             detail_dict.update(detail)
         elif detail is not None:
-            detail_dict['detail'] = detail
+            detail_dict["detail"] = detail
 
         if code is not None:
-            detail_dict['code'] = code
+            detail_dict["code"] = code
 
         super().__init__(detail_dict)
 
@@ -35,5 +35,5 @@ class AuthenticationFailed(DetailDictMixin, exceptions.AuthenticationFailed):
 
 class InvalidToken(AuthenticationFailed):
     status_code = status.HTTP_401_UNAUTHORIZED
-    default_detail = _('Token is invalid or expired')
-    default_code = 'token_not_valid'
+    default_detail = _("Token is invalid or expired")
+    default_code = "token_not_valid"
