@@ -92,11 +92,18 @@ class Token:
         # claim.  We don't want any zombie tokens walking around.
         self.check_exp()
 
-        # Ensure token id is present
-        if api_settings.JTI_CLAIM not in self.payload:
+        # If the defaults are not None then we should enforce the
+        # requirement of these settings.As above, the spec labels
+        # these as optional.
+        if (
+            api_settings.JTI_CLAIM is not None
+            and api_settings.JTI_CLAIM not in self.payload
+        ):
             raise TokenError(_("Token has no id"))
 
-        self.verify_token_type()
+        if api_settings.TOKEN_TYPE_CLAIM is not None:
+
+            self.verify_token_type()
 
     def verify_token_type(self):
         """
@@ -163,8 +170,8 @@ class Token:
             raise TokenError(format_lazy(_("Token has no '{}' claim"), claim))
 
         claim_time = datetime_from_epoch(claim_value)
-        leeway = self.get_token_backend().leeway
-        if claim_time <= current_time - timedelta(seconds=leeway):
+        leeway = self.get_token_backend().get_leeway()
+        if claim_time <= current_time - leeway:
             raise TokenError(format_lazy(_("Token '{}' claim has expired"), claim))
 
     @classmethod
